/***************************************************************************
*   Copyright (C) 2001 by Rick L. Vinyard, Jr.                            *
*   rvinyard@cs.nmsu.edu                                                  *
*                                                                         *
 *   The conexus library is free software; you can redistribute it and/or  *
 *   modify it under the terms of the GNU General Public License           *
 *   version 3 as published by the Free Software Foundation.               *
 *                                                                         *
 *   The conexus library is distributed in the hope that it will be        *
 *   useful, but WITHOUT ANY WARRANTY; without even the implied warranty   *
 *   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU   *
 *   General Public License for more details.                              *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this software. If not see <http://www.gnu.org/licenses/>.  *
 ***************************************************************************/
#ifndef CONEXUSEXCEPT_NSS_H
#define CONEXUSEXCEPT_NSS_H

#include <conexus/except.h>
#include <iostream>

namespace Conexus {

  /**
   * Base class for all nss exceptions.
   * @author Rick L Vinyard Jr
   * @ingroup nspr
   */
  class nss_exception: public conexus_exception {
    public:
      nss_exception( int e = 0 ) : conexus_exception( "Unknown NSS exception.", e, "nss" ) { }
      nss_exception( const std::string s, int e = 0 ) : conexus_exception( s, e, "nss" ) { }
    }
  ;

  namespace exception {


    namespace nss {

      /**
       * Failure importing NSPR socket into NSS
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
      class ssl_socket_import: public nss_exception {
        public:
          ssl_socket_import() : nss_exception( "Error importing NSPR socket into NSS." ) { }
        }
      ;

      /**
       * Failure setting option SSL_SECURITY
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class option_ssl_security: public nss_exception {
    public:
    option_ssl_security() : nss_exception( "Error setting option SSL_SECURITY." ) { }
    }
    ;

      /**
       * Failure setting option SSL_HANDSHAKE_AS_SERVER
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class option_ssl_handshake_as_server: public nss_exception {
    public:
    option_ssl_handshake_as_server() : nss_exception( "Error setting option SSL_HANDSHAKE_AS_SERVER." ) { }
    }
    ;

      /**
       * Failure setting option SSL_HANDSHAKE_AS_CLIENT
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class option_ssl_handshake_as_client: public nss_exception {
    public:
    option_ssl_handshake_as_client() : nss_exception( "Error setting option SSL_HANDSHAKE_AS_CLIENT." ) { }
    }
    ;

          /**
       * Failure setting option SSL_REQUEST_CERTIFICATE
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class option_ssl_request_certificate: public nss_exception {
    public:
    option_ssl_request_certificate() : nss_exception( "Error setting option SSL_REQUEST_CERTIFICATE." ) { }
    }
    ;

          /**
       * Failure setting option SSL_REQUIRE_CERTIFICATE
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class option_ssl_require_certificate: public nss_exception {
    public:
    option_ssl_require_certificate() : nss_exception( "Error setting option SSL_REQUIRE_CERTIFICATE." ) { }
    }
    ;

          /**
       * Failure setting callback SSL_GetClientAuthDataHook
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class ssl_getclientauthdatahook: public nss_exception {
    public:
    ssl_getclientauthdatahook() : nss_exception( "Error setting callback SSL_GetClientAuthDataHook." ) { }
    }
    ;

          /**
       * Failure setting callback SSL_AuthCertificateHook
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class ssl_authcertificatehook: public nss_exception {
    public:
    ssl_authcertificatehook() : nss_exception( "Error setting callback SSL_AuthCertificateHook." ) { }
    }
    ;

          /**
       * Failure setting callback SSL_BadCertHook
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class ssl_badcerthook: public nss_exception {
    public:
    ssl_badcerthook() : nss_exception( "Error setting callback SSL_BadCertHook." ) { }
    }
    ;

          /**
       * Failure setting callback SSL_HandshakeCallback
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class ssl_handshakecallback: public nss_exception {
    public:
    ssl_handshakecallback() : nss_exception( "Error setting callback SSL_HandshakeCallback." ) { }
    }
    ;

          /**
       * Failure setting SSL_PKCS11PinArg
       * @author Rick L Vinyard Jr
       * @ingroup exceptions
       */
    class ssl_pkcs11pinarg: public nss_exception {
    public:
    ssl_pkcs11pinarg() : nss_exception( "Error setting SSL_PKCS11PinArg." ) { }
    }
    ;


      }
    }
  }

#endif
